from bluer_ai.help.web.get_ip import help_get_ip
from bluer_ai.help.web.identify import help_identify
from bluer_ai.help.web.is_accessible import help_is_accessible
from bluer_ai.help.web.open import help_open
from bluer_ai.help.web.share import help_share
from bluer_ai.help.web.where_am_i import help_where_am_i


help_functions = {
    "get_ip": help_get_ip,
    "identify": help_identify,
    "is_accessible": help_is_accessible,
    "open": help_open,
    "share": help_share,
    "where_am_i": help_where_am_i,
}
